/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.position;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum Positions {

    INITIAL {
        @Override
        public Position getPosition() {
            Position position = FACTORY.create();
            position.initial();
            return position;
        }
    },

    EMPTY {
        @Override
        public Position getPosition() {
            Position position = FACTORY.create();
            position.clear();
            return position;
        }
    };

    public abstract Position getPosition();

    static class Factory {

        private Factory() {
        }

        Position create() {
            return create(
                    PositionType.GAME
            );
        }

        Position create(PositionType type) {
            Position position;
            switch (type) {
                case DIAGRAM:
                    position = new DiagramPosition();
                    break;
                case GAME:
                default:
                    position = new GamePosition();
            }
            return position;
        }

    }

    private static final Factory FACTORY = new Factory();

}
