/*
 * Copyright (c) 2018-2019. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.img.fs;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.nio.file.FileSystem;
import java.nio.file.FileSystems;
import java.nio.file.Path;

import org.hedgecode.chess.img.FilenameUtils;

/**
 * Default FileSystem contractor.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class DefFileSystemContractor implements FileSystemContractor {

    private FileSystem fileSystem;
    private String rootPath;

    DefFileSystemContractor(URI uri) {
        fileSystem = FileSystems.getDefault();
        rootPath = FilenameUtils.fixPath(uri.getPath());
    }

    @Override
    public FileSystem getFileSystem() {
        return fileSystem;
    }

    @Override
    public Path getPath(String path) {
        return fileSystem.getPath(rootPath, path);
    }

    @Override
    public InputStream getResourceAsStream(Path file) throws IOException {
        return new FileInputStream(file.toString());
    }

    @Override
    public void close() throws Exception {
        // do nothing
    }

}
