/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.uci;

import java.io.File;
import java.nio.file.Paths;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class CommandEnvironment {

    private static final String ENGINE_BIN_DIR = Paths.get("bin").toAbsolutePath().toString();

    public static void main(String... args) throws Exception {

        EngineRunner engineRunner = new ExternalEngineRunner(
                ENGINE_BIN_DIR + File.separator + "stockfish.exe" // "houdini.exe" "komodo.exe"
        );
        Engine engine = engineRunner.init();

        AcceptorRunner acceptorRunner = new ConsoleAcceptorRunner(); // new AcceptorStubRunner();
        Acceptor acceptor = acceptorRunner.init();

        CommandExecutor commandExecutor = SyncCommandExecutor.Factory.create(engine, acceptor);

        engineRunner.run(commandExecutor);
        acceptorRunner.run(commandExecutor);
    }

}
