/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.uci.command;

/**
 * Types of options that UCI Engine can send/receive.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum OptionType {

    /**
     * Checkbox that can either be true or false.
     */
    CHECK ("check"),

    /**
     * Spin wheel that can be an integer in a certain range.
     */
    SPIN ("spin"),

    /**
     * Combo box that can have different predefined strings as a value.
     */
    COMBO ("combo"),

    /**
     * Button that can be pressed to send a command to the engine.
     */
    BUTTON ("button"),

    /**
     * Text field that has a string as a value, an empty string has the value "<empty>".
     */
    STRING ("string");

    private String type;

    OptionType(String type) {
        this.type = type;
    }

    public String type() {
        return type;
    }

    public static OptionType get(String type) {
        for (OptionType optionType : OptionType.values()) {
            if (optionType.type().equals(type))
                return optionType;
        }
        return null;
    }

}
